This function calculate NDVI value from input near-infrared (NIR) and red bands images. If change the input from red band into green or red-edge band values, it will return GNDVI or NDRE values.
NDVI(NIR, R)a dataframe or matrix contains NIR band values.
a dataframe or matrix contains red band values, NIR and R should have same class and dimension..
A matrix or dataframe(depends on the class of NIR and R).
De Swaef, T., Maes, W. H., Aper, J., Baert, J., Cougnon, M., Reheul, D., ... & Lootens, P. (2021). Applying RGB-and thermal-based vegetation indices from UAVs for high-throughput field phenotyping of drought tolerance in forage grasses. Remote Sensing, 13(1), 147.